@@ -6,39 +6,38 @@ use warnings;
 
 =head1 NAME
 
-App::ZFSCurses - a curses UI to query and modify a ZFS dataset properties.
+App::ZFSCurses - Application namespace.
 
 =head1 VERSION
 
-Version 1.100.
+Version 1.200.
 
 =cut
 
-our $VERSION = '1.100';
-
-=head1 SYNOPSIS
-
-App::ZFSCurses is a curses UI to query and modify a ZFS dataset properties.
-
-=cut
+our $VERSION = '1.200';
 
 =head1 MODULES
 
-App::ZFSCurses is composed of 4 modules, namely:
+The App::ZFSCurses namespace is composed of 5 modules, namely:
 
-=over 4
+=over 5
 
-=item L<App::ZFSCurses::UI>
+=item L<App::ZFSCurses::UI::Datasets>
 
-Draw the UI components.
+Draw UI components showing a list of ZFS datasets.
+
+=item L<App::ZFSCurses::UI::Snapshots>
+
+Draw UI components showing a list of ZFS snapshots.
 
 =item L<App::ZFSCurses::Text>
 
-Return the text messages for various UI components.
+Return texts for various UI components.
 
 =item L<App::ZFSCurses::Backend>
 
-Perform so-called backend operations i.e. running commands.
+Perform backend operations i.e. run commands, capture results and return those
+results to the UI.
 
 =item L<App::ZFSCurses::WidgetFactory>
 
